@@ -1,3 +1,4 @@
+from psycopg2 import sql
 import psycopg2
 import json
 
@@ -158,8 +159,8 @@ class Postgres_Handler:
         table_name = kwargs[self.table_name_key]
         
         #Begining of the SQL query
-        query_start = 'INSERT INTO %(table_name)s'
-        values_dict[self.table_name_key] = table_name
+        query_start = f'INSERT INTO {{self.table_name_key}}'
+        values_dict[self.table_name_key] = sql.Identifier(table_name)
         
         #Iterates through the arguments adds the key to the column_name, and the value to the column_value
         for key, value in kwargs.items():
